| bbox_cql | R Documentation |
Constructs a spatial ECQL BBOX expression from a reference geometry.
bbox_cql(x, geom_name, crs)
x |
An |
geom_name |
Character string giving the geometry attribute name of the WFS layer. |
crs |
A CRS definition (as accepted by |
The bounding box is computed from the geometry provided in x, after
transforming it to the CRS of the target WFS layer. If the layer CRS has
a valid EPSG code, it is included in the ECQL expression.
This function is an internal helper used by spatial_cql() and should
not be called directly by users.
A character string containing a BBOX ECQL filter.
spatial_cql()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.