spatial_cql: Build a spatial ECQL filter

View source: R/predicates.R

spatial_cqlR Documentation

Build a spatial ECQL filter

Description

Converts a spatial predicate and a reference geometry into an ECQL expression suitable for use in a WFS GetFeature request.

Usage

spatial_cql(x, layer, predicate)

Arguments

x

An sf or sfc

layer

character giving the WFS layer name.

predicate

A spatial predicate object created by predicate helpers.

Details

This function is an internal helper used by get_wfs() to translate spatial predicate objects (see spatial_predicates) into ECQL syntax understood by the WFS server.

Users should not call this function directly.

Value

A character string containing a spatial ECQL filter.


happign documentation built on Feb. 19, 2026, 9:06 a.m.