| spatial_cql | R Documentation |
Converts a spatial predicate and a reference geometry into an ECQL
expression suitable for use in a WFS GetFeature request.
spatial_cql(x, layer, predicate)
x |
An |
layer |
|
predicate |
A spatial predicate object created by predicate helpers. |
This function is an internal helper used by get_wfs() to translate
spatial predicate objects (see spatial_predicates) into ECQL syntax understood by the WFS server.
Users should not call this function directly.
A character string containing a spatial ECQL filter.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.